/**
 * GMyth Library
 *
 * @file gmyth/gmyth_remote_encoder.h
 * 
 * @brief <p> GMythRemoteEncoder class defines functions for playing live tv.
 *
 * Copyright (C) 2006 INdT - Instituto Nokia de Tecnologia.
 * @author Hallyson Luiz de Morais Melo <hallyson.melo@indt.org.br>
 *
 *//*
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __GMYTH_REMOTE_ENCODER_H__
#define __GMYTH_REMOTE_ENCODER_H__

#include <glib-object.h>

#include "gmyth_socket.h"

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <netdb.h>
#include <sys/socket.h>
#include <unistd.h>

G_BEGIN_DECLS

#define GMYTH_REMOTE_ENCODER_TYPE               (gmyth_remote_encoder_get_type ())
#define GMYTH_REMOTE_ENCODER(obj)               (G_TYPE_CHECK_INSTANCE_CAST ((obj), GMYTH_REMOTE_ENCODER_TYPE, GMythRemoteEncoder))
#define GMYTH_REMOTE_ENCODER_CLASS(klass)       (G_TYPE_CHECK_CLASS_CAST ((klass), GMYTH_REMOTE_ENCODER_TYPE, GMythRemoteEncoderClass))
#define IS_GMYTH_REMOTE_ENCODER(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GMYTH_REMOTE_ENCODER_TYPE))
#define IS_GMYTH_REMOTE_ENCODER_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GMYTH_REMOTE_ENCODER_TYPE))
#define GMYTH_REMOTE_ENCODER_GET_CLASS(obj)     (G_TYPE_INSTANCE_GET_CLASS ((obj), GMYTH_REMOTE_ENCODER_TYPE, GMythRemoteEncoderClass))


typedef struct _GMythRemoteEncoder         GMythRemoteEncoder;
typedef struct _GMythRemoteEncoderClass    GMythRemoteEncoderClass;

struct _GMythRemoteEncoderClass
{
  GObjectClass parent_class;

  /* callbacks */
  /* no one for now */
};

struct _GMythRemoteEncoder
{
    GObject parent;

    /* socket descriptor */
    GMythSocket *myth_socket;
    
    int recorder_num;
    GString *hostname;
    int port;
};


GType   gmyth_remote_encoder_get_type   (void);

GMythRemoteEncoder* gmyth_remote_encoder_new    (int num,
                                                 GString *hostname,
                                                 gshort port);

gboolean gmyth_remote_encoder_setup     (GMythRemoteEncoder *encoder);
gboolean gmyth_remote_encoder_spawntv   (GMythRemoteEncoder *remote_encoder,
                                         GString *tvchain_id);
gboolean gmyth_remote_encoder_stop_livetv (GMythRemoteEncoder *remote_encoder);

G_END_DECLS

#endif /* __GMYTH_REMOTE_ENCODER_H__ */
